Learn R Programming

coefplot (version 1.1.8)

buildPlotting.lm: Coefplot plotting

Description

Build ggplot object for coefplot

Usage

buildPlotting.lm(modelCI, modelMeltInner = NULL,
    modelMeltOuter = NULL, title = "Coefficient Plot",
    xlab = "Value", ylab = "Coefficient", lwdInner = 1,
    lwdOuter = 0, color = "blue", cex = 0.8, textAngle = 0,
    numberAngle = 0, outerCI = 2, innerCI = 1,
    multi = FALSE, zeroColor = "grey", zeroLWD = 1,
    zeroType = 2, numeric = FALSE, fillColor = "grey",
    alpha = 1/2, horizontal = FALSE, facet = FALSE,
    scales = "free")

Arguments

modelCI
An object created by buildModelCI
modelMeltInner
The inner SE part of the object built by meltModelCI
modelMeltOuter
The outer SE part of the object built by meltModelCI
title
The name of the plot, if NULL then no name is given
xlab
The x label
ylab
The y label
innerCI
How wide the inner confidence interval should be, normally 1 standard deviation. If 0, then there will be no inner confidence interval.
outerCI
How wide the outer confidence interval should be, normally 2 standard deviations. If 0, then there will be no outer confidence interval.
multi
logical; If this is for multiplot then dodge the geoms
lwdInner
The thickness of the inner confidence interval
lwdOuter
The thickness of the outer confidence interval
color
The color of the points and lines
cex
The text size multiplier, currently not used
textAngle
The angle for the coefficient labels, 0 is horizontal
numberAngle
The angle for the value labels, 0 is horizontal
zeroColor
The color of the line indicating 0
zeroLWD
The thickness of the 0 line
zeroType
The type of 0 line, 0 will mean no line
facet
logical; If the coefficients should be faceted by the variables, numeric coefficients (including the intercept) will be one facet
scales
The way the axes should be treated in a faceted plot. Can be c("fixed", "free", "free_x", "free_y")
numeric
logical; If true and factors has exactly one value, then it is displayed in a horizontal graph with constinuous confidence bounds.
fillColor
The color of the confidence bounds for a numeric factor
alpha
The transparency level of the numeric factor's confidence bound
horizontal
logical; If the plot should be displayed horizontally

Value

  • a ggplot graph object

Details

This function builds up the ggplot layer by layer for coefplot.lm

See Also

coefplot.lm coefplot multiplot

Examples

Run this code
data(diamonds)
model1 <- lm(price ~ carat + cut, data=diamonds)
theCI <- coefplot:::buildModelCI(model1)
theCIMelt <- coefplot:::meltModelCI(theCI)
coefplot:::buildPlotting.lm(theCI, theCIMelt$modelMeltInner, theCIMelt$modelMeltInner)

Run the code above in your browser using DataLab