Learn R Programming

coefplot (version 1.1.8)

coefplot.lm: Dotplot for lm coefficients

Description

A graphical display of the coefficients and standard errors from a fitted lm model

Usage

## S3 method for class 'lm':
coefplot(model, title = "Coefficient Plot",
    xlab = "Value", ylab = "Coefficient", innerCI = 1,
    outerCI = 2, lwdInner = 1, lwdOuter = 0,
    color = "blue", cex = 0.8, textAngle = 0,
    numberAngle = 0, zeroColor = "grey", zeroLWD = 1,
    zeroType = 2, facet = FALSE, scales = "free",
    sort = c("natural", "normal", "magnitude", "size", "alphabetical"),
    decreasing = FALSE, numeric = FALSE,
    fillColor = "grey", alpha = 1/2, horizontal = FALSE,
    factors = NULL, only = NULL, shorten = TRUE,
    intercept = TRUE, plot = TRUE, ...)

Arguments

model
The model we are graphing
title
The name of the plot, if NULL then no name is given
xlab
The x label
ylab
The y label
innerCI
How wide the inner confidence interval should be, normally 1 standard deviation. If 0, then there will be no inner confidence interval.
outerCI
How wide the outer confidence interval should be, normally 2 standard deviations. If 0, then there will be no outer confidence interval.
lwdInner
The thickness of the inner confidence interval
lwdOuter
The thickness of the outer confidence interval
color
The color of the points and lines
cex
The text size multiplier, currently not used
textAngle
The angle for the coefficient labels, 0 is horizontal
numberAngle
The angle for the value labels, 0 is horizontal
zeroColor
The color of the line indicating 0
zeroLWD
The thickness of the 0 line
zeroType
The type of 0 line, 0 will mean no line
facet
logical; If the coefficients should be faceted by the variables, numeric coefficients (including the intercept) will be one facet
scales
The way the axes should be treated in a faceted plot. Can be c("fixed", "free", "free_x", "free_y")
sort
Determines the sort order of the coefficients. Possible values are c("natural", "normal", "magnitude", "size", "alphabetical")
decreasing
logical; Whether the coefficients should be ascending or descending
numeric
logical; If true and factors has exactly one value, then it is displayed in a horizontal graph with constinuous confidence bounds.
fillColor
The color of the confidence bounds for a numeric factor
alpha
The transparency level of the numeric factor's confidence bound
horizontal
logical; If the plot should be displayed horizontally
intercept
logical; Whether the Intercept coefficient should be plotted
plot
logical; If the plot should be drawn, if false then a data.frame of the values will be returned
factors
Vector of factor variables that will be the only ones shown
only
logical; If factors has a value this determines how interactions are treated. True means just that variable will be shown and not its interactions. False means interactions will be included.
shorten
logical or character; If FALSE then coefficients for factor levels will include their variable name. If TRUE coefficients for factor levels will be stripped of their variable names. If a character vector of variable
...
Arguments passed on to other functions

Value

  • If plot is TRUE then a ggplot object is returned. Otherwise a data.frame listing coeffcients and confidence bands is returned.

Details

coefplot is the S3 generic method for plotting the coefficients from a fitted model. This method also plots coefficients from glm (using coefplot.lm) and rxLinMod models (through a redirection from coefplot.rxLinMod)

See Also

lm glm ggplot coefplot plotcoef

Examples

Run this code
data(diamonds)
head(diamonds)
model1 <- lm(price ~ carat + cut*color, data=diamonds)
model2 <- lm(price ~ carat*color, data=diamonds)
coefplot(model1)
coefplot(model1, shorten=FALSE)
coefplot(model1, shorten=c("cut"))
coefplot(model1, shorten=c("cut"), intercept=FALSE)
coefplot(model1, factors="cut")
coefplot(model1, factors="cut", only=TRUE)
coefplot(model1, facet=TRUE)
coefplot(model2)

Run the code above in your browser using DataLab