Learn R Programming

coefplot (version 1.1.8)

coefplot.rxLinMod: Dotplot for rxLinMod coefficients

Description

A graphical display of the coefficients and standard errors from a fitted rxLinMod model

Usage

## S3 method for class 'rxLinMod':
coefplot(...)

Arguments

...
All arguments are passed on to coefplot.lm. Please see that function for argument information.

Value

Details

coefplot is the S3 generic method for plotting the coefficients from a fitted model. For more information on this function and it's arguments see coefplot.lm

Examples

Run this code
# See coefplot.lm for examples

Run the code above in your browser using DataLab