Learn R Programming

coefplot (version 1.1.8)

getModelInfo.lm: Model Information

Description

Extracts and builds extensive information from lm and glm models

Usage

getModelInfo.lm(model, shorten = TRUE, factors = NULL,
    only = NULL, ...)

Arguments

model
The fitted model with coefficients to be plotted
factors
Vector of factor variables that will be the only ones shown
only
logical; If factors has a value this determines how interactions are treated. True means just that variable will be shown and not its interactions. False means interactions will be included.
shorten
logical or character; If FALSE then coefficients for factor levels will include their variable name. If TRUE coefficients for factor levels will be stripped of their variable names. If a character vector of variable
...
Further arguments

Value

  • Information on the model

Details

Helper function for coefplot

See Also

coefplot.lm

Examples

Run this code
data(diamonds)
model1 <- lm(price ~ carat + cut*color, data=diamonds)
coefplot(model1)

Run the code above in your browser using DataLab